from setuptools import setup

setup(name='handle_distributions',
      version='0.2',
      description='Gaussian and binomial distributions',
      packages=['handle_distributions'],
      author='Chamod perera',
      author_email= 'chamodperera87@gmail.com',
      zip_safe=False)
